'''
Package definition for 'posce.comms'.
'''

from posce.comms import base
from posce.comms import clip
from posce.comms import copy
from posce.comms import drop
from posce.comms import dump
from posce.comms import edit
from posce.comms import find
from posce.comms import list
from posce.comms import make
from posce.comms import move
from posce.comms import repl
from posce.comms import show
from posce.comms import wget
